==================================
 demo3 - python-embedded-launcher
==================================

This is an example with dependencies.

- dependencies are cached locally as wheels (``pip wheel -r requirements.txt``)
- install wheels locally
- a Python distribution is copied
- the launcher exe is created

see ``make_demo_py27.bat`` and ``make_demo_py3.bat`` which execute these
steps for the respective Python version.
